/*
    MPEG Maaate: An Australian MPEG audio analysis toolkit
    Copyright (C) 2000 Commonwealth Scientific and Industrial Research Organisation
    (CSIRO), Australia.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef maaate_brief_H
#define maaate_brief_H

#include "segmentData.H"
#include "plugins.H"
#include "module.H"

typedef struct {
  SegmentData * uno;
  SegmentData * dos;
  SegmentData * tres;
} Trio;

#ifdef __cplusplus
extern "C" {
#endif

SegmentData * 
variance(Plugins * plugins, SegmentData *sd, 
	 double from, double to,
	 double dur);

SegmentData * 
sumScalefactors(Plugins * plugins, SOUNDfile *sfile, 
		double from, double to, 
		int fromSb, int toSb);
    
SegmentData * 
lowNrj(Plugins * plugins, SegmentData *sd, 
		double from, double to, 
		double dur);

SegmentData * 
spectralCentroid(Plugins * plugins, SOUNDfile *sfile, 
		 double from, double to, 
		 int fromSb, int toSb);

double
backgroundNoiseLevel(Plugins * plugins, SegmentData *sd, 
		     double from, double to, 
		     double minDur, double maxInterrupt, 
		     double onsetTime, double releaseTime);

SegmentTable *
silenceSegmentation(Plugins * plugins, SegmentData *sd, 
		    double from, double to,
		    double thresh, double minDur, double maxInterrupt, 
		    double onsetTime, double releaseTime);

SegmentTable *
noiseSegmentation(Plugins * plugins, SegmentData *sd, 
		  double from, double to,
		  double thresh, double minDur, double maxInterrupt,
		  double onsetTime, double releaseTime);

SegmentTable *
segmentation(Plugins * plugins, SegmentData *sd, 
	     double from, double to, 
	     int below, double thresh, 
	     double minDur, double maxInterrupt, 
	     double onsetTime, double releaseTime);
    
ModuleParamList *
histo1D(Plugins * plugins, SegmentData *sd, 
	double from, double to,
	int bins, double starthisto, double endhisto);

SegmentData * 
SBnrj(Plugins * plugins, SOUNDfile *sfile, 
      double from, double to, 
      int fromSb, int toSb);

SegmentData * 
SBmean(Plugins * plugins, SOUNDfile *sfile, 
      double from, double to, 
      int fromSb, int toSb);

SegmentData * 
SBrms(Plugins * plugins, SOUNDfile *sfile, 
      double from, double to, 
      int fromSb, int toSb);

SegmentData * 
SBscf(Plugins * plugins, SOUNDfile *sfile, 
      double from, double to, 
      int fromSb, int toSb);

SegmentData * 
SBvalue(Plugins * plugins, SOUNDfile *sfile, 
	double from, double to, 
	int fromSb, int toSb);

SegmentData * 
SBvaluenrj(Plugins * plugins, SOUNDfile *sfile, 
	   double from, double to, 
	   int fromSb, int toSb);

SegmentData * 
SBvaluerms(Plugins * plugins, SOUNDfile *sfile, 
	   double from, double to, 
	   int fromSb, int toSb);

SegmentData * 
SBvaluemean(Plugins * plugins, SOUNDfile *sfile, 
	    double from, double to, 
	    int fromSb, int toSb);

SegmentData * 
BandNrjRatio(Plugins * plugins, SOUNDfile *sfile, 
	     double from, double to, 
	     int I, int w_nb);
  
Trio 
bandwidth(Plugins * plugins, SOUNDfile *sfile, 
	  double from, double to, 
	  double Ts);

SegmentData *
sigSb(Plugins * plugins, SOUNDfile *sfile, 
      double from, double to, 
      double Ts);


SegmentData * 
centralMoment(Plugins * plugins, SOUNDfile *sfile, 
	      double from, double to, 
	      int fromSb, int toSb,
	      double duration, int k);

SegmentData * 
signalnrj(Plugins * plugins, SOUNDfile *sfile, 
	  double from, double to,
	  int w_nb);

SegmentData * 
bandNrj(Plugins * plugins, SOUNDfile *sfile, 
	double from, double to,
	int fromSb, int toSb,
	int w_nb);

SegmentData * 
spectralFlux(Plugins * plugins, SOUNDfile *sfile, 
	     double from, double to);

SegmentData * 
pauseRate(Plugins * plugins, SegmentData *sd, 
	  double from, double to, 
	  double Ts, double duration);

SegmentData * 
rollOff(Plugins * plugins, SOUNDfile *sfile, 
	double from, double to);

Trio
sigBdwidth(Plugins * plugins, SegmentData *sd, 
	   double from, double to, 
	   double Ts);

SegmentData * 
signalMagnitude(Plugins * plugins, SOUNDfile *sfile, 
		double from, double to,
		int w_nb);


#ifdef __cplusplus
}
#endif

#endif
